# set working directory (see https://stackoverflow.com/a/35842119)
dir = tryCatch({
  # script being sourced
  getSrcDirectory()[1]
}, error = function(e) {
  # script being run in RStudio
  dirname(rstudioapi::getActiveDocumentContext()$path)
})
setwd(dir)

library(data.table)

projects_comparison <- fread("data/comparison_project_sample.csv", header=TRUE, sep=",", quote="\"", strip.white=TRUE, showProgress=TRUE, encoding="UTF-8", na.strings=c("", "null"))
nrow(projects_comparison)
# 8,405

# exclude TravisTorrent projects
tr_projects <- read.csv("data/tr_projects.csv", header=TRUE, sep=",", quote="\"", na.strings=c(""), stringsAsFactors=FALSE)
length(unique(tr_projects$gh_project_name))
# 1283

projects_comparison <- projects_comparison[!(projects_comparison$repo_name %in% unique(tr_projects$gh_project_name)),]
nrow(projects_comparison)
# 8,046 (359 excluded)

# draw new sample
sample_comparison <- projects_comparison[sample(nrow(projects_comparison), 800),]

# write sample to CSV files
write.table(sample_comparison, file="data/comparison_project_sample_800.csv", sep=",", col.names=TRUE, row.names=FALSE, na="", quote=TRUE, qmethod="double", fileEncoding="UTF-8")
